@@ -432,8 +432,13 @@ depsGraphDeps rev rpmopts verbose excludedPkgs ignoredBRs lenient mdir pkgs deps
   unlessM (and <$> mapM doesDirectoryExist pkgs) $
     errorWithoutStackTrace "Please use package directory paths"
   -- filter out dotfiles
-  createGraph3 ignoredBRs rpmopts verbose lenient (not rev) mdir (filter (\d -> d `notElem` excludedPkgs && head d /= '.') deps) >>=
+  createGraph3 ignoredBRs rpmopts verbose lenient (not rev) mdir
+    (filter (\d -> d `notElem` excludedPkgs && not ("." `isPrefixOf` d)) $ pkgsAndDeps pkgs deps) >>=
     createGraph2 rpmopts verbose lenient True mdir . dependencyNodes pkgs
+  where
+    pkgsAndDeps [] ds = ds
+    pkgsAndDeps (p:ps) ds =
+      pkgsAndDeps ps $ if p `elem` ds then ds else p : ds
 
 -- | Used to control the output from sortGraph
 data Components = Parallel -- ^ separate independent stacks
